@@ -1,12 +1,12 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 package Mail::Box::File::Message;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.095';
 
 use base 'Mail::Box::Message';
 
@@ -37,7 +37,7 @@ sub write(;$)
     my $escaped = $self->escapedBody;
     $out->print($self->fromLine);
 
-    my $size  = sum map {length($_)} @$escaped;
+    my $size  = sum 0, map {length($_)} @$escaped;
 
     my $head  = $self->head;
     $head->set('Content-Length' => $size); 
