@@ -8,7 +8,7 @@ use warnings;
 
 package Mail::Box::Maildir::Message;
 use vars '$VERSION';
-$VERSION = '2.094';
+$VERSION = '2.095';
 
 use base 'Mail::Box::Dir::Message';
 
@@ -82,7 +82,7 @@ sub labelsToFilename()
     my $old    = $self->filename;
 
     my ($folderdir, $set, $oldname)
-      = $old =~ m!(.*)/(new|cur|tmp)/([^:]*)(\:[^:]*)?$!;
+      = $old =~ m!(.*)/(new|cur|tmp)/(.+?)(\:2,[^:]*)?$!;
 
     my $newflags    # alphabeticly ordered!
       = ($labels->{draft}   ? 'D' : '')
@@ -99,7 +99,8 @@ sub labelsToFilename()
         $folder->modified(1) if defined $folder;
     }
 
-    my $new = File::Spec->catfile($folderdir, $newset, "$oldname:2,$newflags");
+    my $new = File::Spec->catfile($folderdir, $newset
+      , $oldname . ($newset eq 'new' && $newflags eq '' ? '' : ":2,$newflags"));
 
     if($new ne $old)
     {   unless(move $old, $new)
