@@ -1,9 +1,14 @@
+# Copyrights 2001-2010 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.095';
+
 use base 'Mail::Reporter';
 
 use Mail::Message::Part;
@@ -63,8 +68,6 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub clone(@)
 {   my ($self, %args) = @_;
@@ -104,40 +107,29 @@ sub clone(@)
 sub messageId() { $_[0]->{MM_message_id} || $_[0]->takeMessageId}
 sub messageID() {shift->messageId}   # compatibility
 
-#------------------------------------------
-
 
 sub container() { undef } # overridden by Mail::Message::Part
 
-#------------------------------------------
-
 
 sub isPart() { 0 } # overridden by Mail::Message::Part
 
-#------------------------------------------
-
 
 sub toplevel() { shift } # overridden by Mail::Message::Part
 
-#------------------------------------------
-
 
 sub isDummy() { 0 }
 
-#------------------------------------------
-
 
 sub print(;$)
 {   my $self = shift;
     my $out  = shift || select;
 
     $self->head->print($out);
-    $self->body->print($out);
+    my $body = $self->body;
+    $body->print($out) if $body;
     $self;
 }
 
-#------------------------------------------
-
 
 sub write(;$)
 {   my $self = shift;
@@ -148,8 +140,6 @@ sub write(;$)
     $self;
 }
 
-#------------------------------------------
-
 
 my $default_mailer;
 
@@ -174,8 +164,6 @@ sub send(@)
     $mailer->send($self, %args);
 }
 
-#------------------------------------------
-
 
 sub size()
 {   my $self = shift;
@@ -211,8 +199,6 @@ sub head(;$)
     $head;
 }
 
-#------------------------------------------
-
 
 sub get($)
 {   my $self  = shift;
@@ -220,24 +206,18 @@ sub get($)
     $field->body;
 }
 
-#------------------------------------------
-
 
 sub study($)
 {  my $head = shift->head or return;
    scalar $head->study(@_);    # return only last
 }
 
-#-------------------------------------------
-
 
 sub from()
 {  my $from = shift->head->get('From') or return ();
    map {$_->addresses} $from;
 }
 
-#-------------------------------------------
-
 
 sub sender()
 {   my $self   = shift;
@@ -247,26 +227,15 @@ sub sender()
     ($sender->addresses)[0];                 # first specified address
 }
 
-#-------------------------------------------
-
 
 sub to() { map {$_->addresses} shift->head->get('To') }
 
-#-------------------------------------------
-
 
 sub cc() { map {$_->addresses} shift->head->get('Cc') }
 
-#-------------------------------------------
-
 
 sub bcc() { map {$_->addresses} shift->head->get('Bcc') }
 
-#-------------------------------------------
-
-
-#-------------------------------------------
-
 
 sub destinations()
 {   my $self = shift;
@@ -275,29 +244,21 @@ sub destinations()
     values %to;
 }
 
-#-------------------------------------------
-
 
 sub subject()
 {   my $subject = shift->get('subject');
     defined $subject ? $subject : '';
 }
 
-#-------------------------------------------
-
 
 sub guessTimestamp() {shift->head->guessTimestamp}
 
-#-------------------------------------------
-
 
 sub timestamp()
 {   my $head = shift->head;
     $head->recvstamp || $head->timestamp;
 }
 
-#------------------------------------------
-
 
 sub nrLines()
 {   my $self = shift;
@@ -328,6 +289,7 @@ sub body(;$@)
     # Bodies of real messages must be encoded for safe transmission.
     # Message parts will get encoded on the moment the whole multipart
     # is transformed into a real message.
+
     my $body = $self->isPart ? $rawbody : $rawbody->encoded;
     $body->contentInfoTo($self->head);
 
@@ -340,40 +302,38 @@ sub body(;$@)
     $self->{MM_body} = $body;
 }
 
-#------------------------------------------
-
 
 sub decoded(@)
 {   my ($self, %args) = @_;
 
-    return $self->{MB_decoded} if $self->{MB_decoded};
-
     my $body    = $self->body->load or return;
-    my $decoded = $body->decoded(result_type => $args{result_type});
+    my $decoded = $body->decoded
+      ( result_type => $args{result_type}
+      , charset     => $args{charset}
+      );
 
-    $self->{MB_decoded} = $decoded if $args{keep};
     $decoded;
 }
 
-#------------------------------------------
-
 
 sub encode(@)
 {   my $body = shift->body->load;
     $body ? $body->encode(@_) : undef;
 }
 
-#-------------------------------------------
-
 
 sub isMultipart() {shift->head->isMultipart}
 
-#-------------------------------------------
-
 
 sub isNested() {shift->body->isNested}
 
-#-------------------------------------------
+
+sub contentType()
+{   my $head = shift->head;
+    my $ct   = (defined $head ? $head->get('Content-Type', 0) : undef) || '';
+    $ct      =~ s/\s*\;.*//;
+    length $ct ? $ct : 'text/plain';
+}
 
 
 sub parts(;$)
@@ -414,8 +374,6 @@ sub modified(;$)
     $flag;
 }
 
-#------------------------------------------
-
 
 sub isModified()
 {   my $self = shift;
@@ -436,8 +394,6 @@ sub isModified()
     0;
 }
 
-#------------------------------------------
-
 
 sub label($;$@)
 {   my $self   = shift;
@@ -449,21 +405,15 @@ sub label($;$@)
     $return;
 }
 
-#------------------------------------------
-
 
 sub labels()
 {   my $self = shift;
     wantarray ? keys %{$self->{MM_labels}} : $self->{MM_labels};
 }
 
-#------------------------------------------
-
 
 sub isDeleted() { shift->label('deleted') }
 
-#-------------------------------------------
-
 
 sub delete()
 {  my $self = shift;
@@ -471,8 +421,6 @@ sub delete()
    $old || $self->label(deleted => time);
 }
 
-#-------------------------------------------
-
 
 sub deleted(;$)
 {   my $self = shift;
@@ -481,8 +429,6 @@ sub deleted(;$)
        : $self->label('deleted')   # compat 2.036
 }
 
-#-------------------------------------------
-
 
 sub labelsToStatus()
 {   my $self    = shift;
@@ -509,8 +455,6 @@ sub labelsToStatus()
     $self;
 }
 
-#-------------------------------------------
-
 
 sub statusToLabels()
 {   my $self    = shift;
@@ -538,15 +482,16 @@ sub statusToLabels()
 #------------------------------------------
 
 
-#------------------------------------------
-
-
 my $mail_internet_converter;
 my $mime_entity_converter;
+my $email_simple_converter;
 
 sub coerce($@)
 {   my ($class, $message) = @_;
 
+    ref $message
+        or die "coercion starts with some object";
+
     return bless $message, $class
         if $message->isa(__PACKAGE__);
 
@@ -554,7 +499,6 @@ sub coerce($@)
     {   unless($mime_entity_converter)
         {   eval {require Mail::Message::Convert::MimeEntity};
                 confess "Install MIME::Entity" if $@;
-
             $mime_entity_converter = Mail::Message::Convert::MimeEntity->new;
         }
 
@@ -566,25 +510,37 @@ sub coerce($@)
     {   unless($mail_internet_converter)
         {   eval {require Mail::Message::Convert::MailInternet};
             confess "Install Mail::Internet" if $@;
-
-           $mail_internet_converter = Mail::Message::Convert::MailInternet->new;
+            $mail_internet_converter = Mail::Message::Convert::MailInternet->new;
         }
 
         $message = $mail_internet_converter->from($message)
             or return;
     }
 
+    elsif($message->isa('Email::Simple'))
+    {   unless($email_simple_converter)
+        {   eval {require Mail::Message::Convert::EmailSimple};
+            confess "Install Email::Simple" if $@;
+            $email_simple_converter = Mail::Message::Convert::EmailSimple->new;
+        }
+
+        $message = $email_simple_converter->from($message)
+            or return;
+    }
+
+    elsif($message->isa('Email::Abstract'))
+    {   return $class->coerce($message->object);
+    }
+
     else
-    {   my $what = ref $message ? 'a'.ref($message).' object' : 'text';
-        confess "Cannot coerce $what into a ". __PACKAGE__." object.\n";
+    {   $class->log(INTERNAL =>  "Cannot coerce a ". ref($message)
+              . " object into a ". __PACKAGE__." object");
     }
 
     $message->{MM_modified}  ||= 0;
     bless $message, $class;
 }
 
-#------------------------------------------
-
 
 sub clonedFrom() { shift->{MM_cloned} }
 
@@ -593,8 +549,6 @@ sub clonedFrom() { shift->{MM_cloned} }
 sub isParsed()   { not shift->isDelayed }
 sub headIsRead() { not shift->head->isa('Mail::Message::Delayed') }
 
-#------------------------------------------
-
 
 sub readFromParser($;$)
 {   my ($self, $parser, $bodytype) = @_;
@@ -614,8 +568,6 @@ sub readFromParser($;$)
     $self;
 }
 
-#------------------------------------------
-
 
 sub readHead($;$)
 {   my ($self, $parser) = (shift, shift);
@@ -630,8 +582,6 @@ sub readHead($;$)
       )->read($parser);
 }
 
-#------------------------------------------
-
 
 my $mpbody = 'Mail::Message::Body::Multipart';
 my $nbody  = 'Mail::Message::Body::Nested';
@@ -648,12 +598,13 @@ sub readBody($$;$$)
     my $body;
     if($bodytype->isDelayed)
     {   $body = $bodytype->new
-          ( message           => $self
+          ( message => $self
+          , charset => 'us-ascii'
           , $self->logSettings
           );
     }
     else
-    {   my $ct   = $head->get('Content-Type');
+    {   my $ct   = $head->get('Content-Type', 0);
         my $type = defined $ct ? lc($ct->body) : 'text/plain';
 
         # Be sure you have acceptable bodies for multiparts and nested.
@@ -663,8 +614,9 @@ sub readBody($$;$$)
         {   $bodytype = $nbody  }
 
         $body = $bodytype->new
-        ( message           => $self
-        , checked           => $self->{MM_trusted}
+        ( message => $self
+        , checked => $self->{MM_trusted}
+        , charset => 'us-ascii'
         , $self->logSettings
         );
 
@@ -680,8 +632,6 @@ sub readBody($$;$$)
       );
 }
 
-#------------------------------------------
-
 
 sub storeBody($)
 {   my ($self, $body) = @_;
@@ -690,16 +640,12 @@ sub storeBody($)
     $body;
 }
 
-#-------------------------------------------
-
 
 sub isDelayed()
 {    my $body = shift->body;
      !$body || $body->isDelayed;
 }
 
-#------------------------------------------
-
 
 sub takeMessageId(;$)
 {   my $self  = shift;
@@ -732,8 +678,6 @@ sub shortSize(;$)
     :                      sprintf "%3.0fM", $size/(1024*1024);
 }
 
-#------------------------------------------
-
 
 sub shortString()
 {   my $self    = shift;
@@ -752,8 +696,6 @@ sub DESTROY()
     $self->body(undef);
 }
 
-#------------------------------------------
-
 
 sub destruct() { $_[0] = undef }
 
