@@ -1,4 +1,4 @@
-# Copyrights 2001-2009 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 1.06.
@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '2.090';
+$VERSION = '2.095';
 
 use base 'Mail::Message::Body';
 
@@ -92,7 +92,7 @@ sub clone()
 
 sub nrLines()
 {   my $self = shift;
-    my $nr   = 1;     # trailing boundary
+    my $nr   = 1;  # trailing part-sep
 
     if(my $preamble = $self->preamble)
     {   $nr += $preamble->nrLines;
@@ -104,7 +104,10 @@ sub nrLines()
         $nr++ if $part->body->endsOnNewline;
     }
 
-    if(my $epilogue = $self->epilogue) { $nr += $epilogue->nrLines }
+    if(my $epilogue = $self->epilogue)
+    {   $nr += $epilogue->nrLines;
+    }
+
     $nr;
 }
 
@@ -118,8 +121,9 @@ sub size()
     else { $bytes -= 1 }      # no leading \n
 
     $bytes += $bbytes + $_->size foreach $self->parts('ACTIVE');
-    if(my $epilogue = $self->epilogue) { $bytes += $epilogue->size }
-
+    if(my $epilogue = $self->epilogue)
+    {   $bytes += $epilogue->size;
+    }
     $bytes;
 }
 
@@ -145,10 +149,12 @@ sub lines()
     if(!@lines) { ; }
     elsif($lines[-1] =~ m/\n$/) { push @lines, "\n" }
     else { $lines[-1] .= "\n" }
-    push @lines, "--$boundary--\n";
+    push @lines, "--$boundary--";
 
-    my $epilogue = $self->epilogue;
-    push @lines, $epilogue->lines if $epilogue;
+    if(my $epilogue = $self->epilogue)
+    {   $lines[-1] .= "\n";
+        push @lines, $epilogue->lines;
+    }
 
     wantarray ? @lines : \@lines;
 }
@@ -180,7 +186,7 @@ sub print(;$)
             $part->print($out);
         }
         print $out "\n" if $count++;
-        print $out "--$boundary--\n";
+        print $out "--$boundary--";
     }
     else
     {   foreach my $part ($self->parts('ACTIVE'))
@@ -189,10 +195,13 @@ sub print(;$)
             $part->print($out);
         }
         $out->print("\n") if $count++;
-        $out->print("--$boundary--\n");
+        $out->print("--$boundary--");
     }
 
-    if(my $epilogue = $self->epilogue) { $epilogue->print($out) }
+    if(my $epilogue = $self->epilogue)
+    {   $out->print("\n");
+        $epilogue->print($out);
+    }
 
     $self;
 }
@@ -239,8 +248,11 @@ sub read($$$$)
     my $preamble = Mail::Message::Body::Lines->new(@msgopts, @sloppyopts)
        ->read($parser, $head);
 
+    $preamble->nrLines
+        or undef $preamble;
+
     $self->{MMBM_preamble} = $preamble
-        if defined $preamble && $preamble->nrLines > 0;
+        if defined $preamble;
 
     # Get the parts.
 
@@ -264,15 +276,18 @@ sub read($$$$)
     my $epilogue = Mail::Message::Body::Lines->new(@msgopts, @sloppyopts)
         ->read($parser, $head);
 
-    $self->{MMBM_epilogue} = $epilogue
-        if defined $epilogue && $epilogue->nrLines > 0;
-
     my $end = defined $epilogue ? ($epilogue->fileLocation)[1]
-            : @parts            ? ($parts[-1]->fileLocation)[1]
+            : @parts            ? ($parts[-1]->body->fileLocation)[1]
             : defined $preamble ? ($preamble->fileLocation)[1]
             :                      $begin;
-
     $self->fileLocation($begin, $end);
+
+   $epilogue->nrLines
+        or undef $epilogue;
+
+    $self->{MMBM_epilogue} = $epilogue
+        if defined $epilogue;
+
     $self;
 }
 
@@ -395,6 +410,8 @@ sub boundary(;$)
 
 sub endsOnNewline() { 1 }
 
+sub toplevel() { my $msg = shift->message; $msg ? $msg->toplevel : undef}
+
 #-------------------------------------------
 
 
