@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Message::Part;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.095';
 
 use base 'Mail::Message';
 
@@ -34,6 +34,10 @@ sub init($)
 
 sub coerce($@)
 {   my ($class, $thing, $container) = (shift, shift, shift);
+    if($thing->isa($class))
+    {   $thing->container($container);
+        return $thing;
+    }
 
     return $class->buildFromBody($thing, $container, @_)
         if $thing->isa('Mail::Message::Body');
@@ -84,13 +88,6 @@ sub toplevel()
 
 sub isPart() { 1 }
 
-
-sub printEscapedFrom($)
-{   my ($self, $out) = @_;
-    $self->head->print($out);
-    $self->body->printEscapedFrom($out);
-}
-
 sub readFromParser($;$)
 {   my ($self, $parser, $bodytype) = @_;
 
@@ -109,6 +106,14 @@ sub readFromParser($;$)
     $self;
 }
 
+#-----------------
+
+sub printEscapedFrom($)
+{   my ($self, $out) = @_;
+    $self->head->print($out);
+    $self->body->printEscapedFrom($out);
+}
+
 
 sub destruct()
 {  my $self = shift;
